# Generated by roxygen2: do not edit by hand

S3method(format,rd_section_gitcommands)
S3method(print,gert_signature)
S3method(print,git_repo_ptr)
S3method(roxygen2::roxy_tag_parse,roxy_tag_git)
S3method(roxygen2::roxy_tag_rd,roxy_tag_git)
export(git_add)
export(git_ahead_behind)
export(git_archive_zip)
export(git_branch)
export(git_branch_checkout)
export(git_branch_create)
export(git_branch_delete)
export(git_branch_exists)
export(git_branch_fast_forward)
export(git_branch_list)
export(git_branch_move)
export(git_branch_set_upstream)
export(git_branch_switch)
export(git_checkout_pull_request)
export(git_cherry_pick)
export(git_clone)
export(git_commit)
export(git_commit_all)
export(git_commit_descendant_of)
export(git_commit_id)
export(git_commit_info)
export(git_commit_stats)
export(git_config)
export(git_config_get)
export(git_config_global)
export(git_config_global_get)
export(git_config_global_set)
export(git_config_global_unset)
export(git_config_local_get)
export(git_config_set)
export(git_config_unset)
export(git_conflicts)
export(git_diff)
export(git_diff_patch)
export(git_fetch)
export(git_fetch_pull_requests)
export(git_find)
export(git_ignore_path_is_ignored)
export(git_info)
export(git_init)
export(git_log)
export(git_ls)
export(git_merge)
export(git_merge_abort)
export(git_merge_analysis)
export(git_merge_find_base)
export(git_merge_stage_only)
export(git_open)
export(git_pull)
export(git_push)
export(git_rebase_commit)
export(git_rebase_list)
export(git_remote_add)
export(git_remote_info)
export(git_remote_list)
export(git_remote_ls)
export(git_remote_refspecs)
export(git_remote_remove)
export(git_remote_set_pushurl)
export(git_remote_set_url)
export(git_reset_hard)
export(git_reset_mixed)
export(git_reset_soft)
export(git_restore)
export(git_revert)
export(git_rm)
export(git_signature)
export(git_signature_default)
export(git_signature_parse)
export(git_stash_drop)
export(git_stash_list)
export(git_stash_pop)
export(git_stash_save)
export(git_stat_files)
export(git_status)
export(git_submodule_add)
export(git_submodule_fetch)
export(git_submodule_info)
export(git_submodule_init)
export(git_submodule_list)
export(git_submodule_set_to)
export(git_tag_create)
export(git_tag_delete)
export(git_tag_list)
export(git_tag_push)
export(git_worktree_add)
export(git_worktree_exists)
export(git_worktree_is_locked)
export(git_worktree_is_prunable)
export(git_worktree_is_valid)
export(git_worktree_list)
export(git_worktree_lock)
export(git_worktree_path)
export(git_worktree_prune)
export(git_worktree_remove)
export(git_worktree_unlock)
export(libgit2_config)
export(user_is_configured)
importFrom(askpass,askpass)
importFrom(credentials,git_credential_ask)
importFrom(credentials,git_credential_forget)
importFrom(credentials,ssh_key_info)
importFrom(credentials,ssh_read_key)
importFrom(openssl,write_openssh_pem)
importFrom(openssl,write_pem)
importFrom(openssl,write_pkcs1)
importFrom(openssl,write_ssh)
useDynLib(gert,R_git_ahead_behind)
useDynLib(gert,R_git_branch_current)
useDynLib(gert,R_git_branch_exists)
useDynLib(gert,R_git_branch_list)
useDynLib(gert,R_git_branch_move)
useDynLib(gert,R_git_branch_set_target)
useDynLib(gert,R_git_branch_set_upstream)
useDynLib(gert,R_git_checkout_branch)
useDynLib(gert,R_git_checkout_unborn)
useDynLib(gert,R_git_cherry_pick)
useDynLib(gert,R_git_commit_create)
useDynLib(gert,R_git_commit_descendant)
useDynLib(gert,R_git_commit_id)
useDynLib(gert,R_git_commit_info)
useDynLib(gert,R_git_commit_log)
useDynLib(gert,R_git_commit_stats)
useDynLib(gert,R_git_config_list)
useDynLib(gert,R_git_config_set)
useDynLib(gert,R_git_config_unset)
useDynLib(gert,R_git_conflict_list)
useDynLib(gert,R_git_create_branch)
useDynLib(gert,R_git_delete_branch)
useDynLib(gert,R_git_diff_list)
useDynLib(gert,R_git_ignore_path_is_ignored)
useDynLib(gert,R_git_merge_analysis)
useDynLib(gert,R_git_merge_cleanup)
useDynLib(gert,R_git_merge_find_base)
useDynLib(gert,R_git_merge_parent_heads)
useDynLib(gert,R_git_merge_stage)
useDynLib(gert,R_git_rebase)
useDynLib(gert,R_git_remote_add)
useDynLib(gert,R_git_remote_add_fetch)
useDynLib(gert,R_git_remote_fetch)
useDynLib(gert,R_git_remote_info)
useDynLib(gert,R_git_remote_list)
useDynLib(gert,R_git_remote_ls)
useDynLib(gert,R_git_remote_push)
useDynLib(gert,R_git_remote_refspecs)
useDynLib(gert,R_git_remote_remove)
useDynLib(gert,R_git_remote_set_url)
useDynLib(gert,R_git_repository_add)
useDynLib(gert,R_git_repository_clone)
useDynLib(gert,R_git_repository_find)
useDynLib(gert,R_git_repository_info)
useDynLib(gert,R_git_repository_init)
useDynLib(gert,R_git_repository_ls)
useDynLib(gert,R_git_repository_open)
useDynLib(gert,R_git_repository_path)
useDynLib(gert,R_git_repository_rm)
useDynLib(gert,R_git_reset)
useDynLib(gert,R_git_restore)
useDynLib(gert,R_git_revert)
useDynLib(gert,R_git_signature_create)
useDynLib(gert,R_git_signature_default)
useDynLib(gert,R_git_signature_parse)
useDynLib(gert,R_git_stash_drop)
useDynLib(gert,R_git_stash_list)
useDynLib(gert,R_git_stash_pop)
useDynLib(gert,R_git_stash_save)
useDynLib(gert,R_git_stat_files)
useDynLib(gert,R_git_status_list)
useDynLib(gert,R_git_submodule_info)
useDynLib(gert,R_git_submodule_init)
useDynLib(gert,R_git_submodule_list)
useDynLib(gert,R_git_submodule_save)
useDynLib(gert,R_git_submodule_set_to)
useDynLib(gert,R_git_submodule_setup)
useDynLib(gert,R_git_submodule_update)
useDynLib(gert,R_git_tag_create)
useDynLib(gert,R_git_tag_delete)
useDynLib(gert,R_git_tag_list)
useDynLib(gert,R_git_worktree_add)
useDynLib(gert,R_git_worktree_exists)
useDynLib(gert,R_git_worktree_is_locked)
useDynLib(gert,R_git_worktree_is_prunable)
useDynLib(gert,R_git_worktree_is_valid)
useDynLib(gert,R_git_worktree_list)
useDynLib(gert,R_git_worktree_lock)
useDynLib(gert,R_git_worktree_path)
useDynLib(gert,R_git_worktree_prune)
useDynLib(gert,R_git_worktree_unlock)
useDynLib(gert,R_libgit2_config)
useDynLib(gert,R_set_cert_locations)
useDynLib(gert,R_static_libgit2)
