% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/submodules.R
\name{git_submodule_list}
\alias{git_submodule_list}
\alias{git_submodule_info}
\alias{git_submodule_init}
\alias{git_submodule_set_to}
\alias{git_submodule_add}
\alias{git_submodule_fetch}
\title{Submodules}
\usage{
git_submodule_list(repo = ".")

git_submodule_info(submodule, repo = ".")

git_submodule_init(submodule, overwrite = FALSE, repo = ".")

git_submodule_set_to(submodule, ref, checkout = TRUE, repo = ".")

git_submodule_add(url, path = basename(url), ref = "HEAD", ..., repo = ".")

git_submodule_fetch(submodule, ..., repo = ".")
}
\arguments{
\item{repo}{The path to the git repository. If the directory is not a
repository, parent directories are considered (see \code{\link[=git_find]{git_find()}}). To disable
this search, provide the filepath protected with \code{\link[=I]{I()}}. When using this
parameter, always explicitly call by name (i.e. \verb{repo = }) because future
versions of gert may have additional parameters.}

\item{submodule}{name of the submodule}

\item{overwrite}{overwrite existing entries}

\item{ref}{a branch or tag or hash with}

\item{checkout}{actually switch the contents of the directory to this commit}

\item{url}{full git url of the submodule}

\item{path}{relative of the submodule}

\item{...}{extra arguments for \code{\link[=git_fetch]{git_fetch()}} for authentication things}
}
\description{
Interact with \href{https://git-scm.com/book/en/v2/Git-Tools-Submodules}{submodules}
in the repository.
}
\section{Related libgit2 documentation}{\href{https://libgit2.org/docs/reference/main/submodule/index.html}{\code{submodule}}.}

